@@ -172,12 +172,10 @@ module test;
   reg signed [32-1:0] _th_ctrl_araddr_8;
   reg __saxi_cond_6_1;
   reg signed [32-1:0] axim_rdata_14;
-  reg signed [32-1:0] _th_ctrl_v_9;
+  reg signed [32-1:0] _th_ctrl_busy_9;
   reg __saxi_cond_7_1;
   reg signed [32-1:0] axim_rdata_15;
-  reg __saxi_cond_8_1;
-  assign _saxi_rready = (th_ctrl == 21) || (th_ctrl == 25) || (th_ctrl == 30);
-  reg signed [32-1:0] axim_rdata_16;
+  assign _saxi_rready = (th_ctrl == 26) || (th_ctrl == 34);
   reg signed [32-1:0] _th_ctrl_c_10;
   reg signed [32-1:0] _th_ctrl_end_time_11;
   reg signed [32-1:0] _th_ctrl_time_12;
@@ -251,11 +249,9 @@ module test;
     _th_ctrl_araddr_8 = 0;
     __saxi_cond_6_1 = 0;
     axim_rdata_14 = 0;
-    _th_ctrl_v_9 = 0;
+    _th_ctrl_busy_9 = 0;
     __saxi_cond_7_1 = 0;
     axim_rdata_15 = 0;
-    __saxi_cond_8_1 = 0;
-    axim_rdata_16 = 0;
     _th_ctrl_c_10 = 0;
     _th_ctrl_end_time_11 = 0;
     _th_ctrl_time_12 = 0;
@@ -286,7 +282,6 @@ module test;
       _saxi_arvalid <= 0;
       __saxi_cond_6_1 <= 0;
       __saxi_cond_7_1 <= 0;
-      __saxi_cond_8_1 <= 0;
     end else begin
       if(__saxi_cond_0_1) begin
         _saxi_awvalid <= 0;
@@ -312,16 +307,13 @@ module test;
       if(__saxi_cond_7_1) begin
         _saxi_arvalid <= 0;
       end 
-      if(__saxi_cond_8_1) begin
-        _saxi_arvalid <= 0;
-      end 
       if(_saxi_wvalid && _saxi_wready && !(_saxi_bvalid && _saxi_bready) && (outstanding_wcount_0 < 7)) begin
         outstanding_wcount_0 <= outstanding_wcount_0 + 1;
       end 
       if(!(_saxi_wvalid && _saxi_wready) && (_saxi_bvalid && _saxi_bready) && (outstanding_wcount_0 > 0)) begin
         outstanding_wcount_0 <= outstanding_wcount_0 - 1;
       end 
-      if((th_ctrl == 7) && (_saxi_awready || !_saxi_awvalid)) begin
+      if((th_ctrl == 7) && ((outstanding_wcount_0 < 6) && (_saxi_awready || !_saxi_awvalid))) begin
         _saxi_awaddr <= _th_ctrl_awaddr_4;
         _saxi_awvalid <= 1;
       end 
@@ -329,7 +321,7 @@ module test;
       if(_saxi_awvalid && !_saxi_awready) begin
         _saxi_awvalid <= _saxi_awvalid;
       end 
-      if((th_ctrl == 8) && ((outstanding_wcount_0 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
+      if((th_ctrl == 9) && ((outstanding_wcount_0 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
         _saxi_wdata <= _th_ctrl_a_5;
         _saxi_wvalid <= 1;
         _saxi_wstrb <= { 4{ 1'd1 } };
@@ -338,7 +330,7 @@ module test;
       if(_saxi_wvalid && !_saxi_wready) begin
         _saxi_wvalid <= _saxi_wvalid;
       end 
-      if((th_ctrl == 12) && (_saxi_awready || !_saxi_awvalid)) begin
+      if((th_ctrl == 13) && ((outstanding_wcount_0 < 6) && (_saxi_awready || !_saxi_awvalid))) begin
         _saxi_awaddr <= _th_ctrl_awaddr_4;
         _saxi_awvalid <= 1;
       end 
@@ -346,7 +338,7 @@ module test;
       if(_saxi_awvalid && !_saxi_awready) begin
         _saxi_awvalid <= _saxi_awvalid;
       end 
-      if((th_ctrl == 13) && ((outstanding_wcount_0 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
+      if((th_ctrl == 15) && ((outstanding_wcount_0 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
         _saxi_wdata <= _th_ctrl_b_6;
         _saxi_wvalid <= 1;
         _saxi_wstrb <= { 4{ 1'd1 } };
@@ -355,7 +347,7 @@ module test;
       if(_saxi_wvalid && !_saxi_wready) begin
         _saxi_wvalid <= _saxi_wvalid;
       end 
-      if((th_ctrl == 17) && (_saxi_awready || !_saxi_awvalid)) begin
+      if((th_ctrl == 19) && ((outstanding_wcount_0 < 6) && (_saxi_awready || !_saxi_awvalid))) begin
         _saxi_awaddr <= _th_ctrl_awaddr_4;
         _saxi_awvalid <= 1;
       end 
@@ -363,7 +355,7 @@ module test;
       if(_saxi_awvalid && !_saxi_awready) begin
         _saxi_awvalid <= _saxi_awvalid;
       end 
-      if((th_ctrl == 18) && ((outstanding_wcount_0 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
+      if((th_ctrl == 21) && ((outstanding_wcount_0 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
         _saxi_wdata <= 1;
         _saxi_wvalid <= 1;
         _saxi_wstrb <= { 4{ 1'd1 } };
@@ -372,7 +364,7 @@ module test;
       if(_saxi_wvalid && !_saxi_wready) begin
         _saxi_wvalid <= _saxi_wvalid;
       end 
-      if((th_ctrl == 20) && (_saxi_arready || !_saxi_arvalid)) begin
+      if((th_ctrl == 24) && (_saxi_arready || !_saxi_arvalid)) begin
         _saxi_araddr <= _th_ctrl_araddr_8;
         _saxi_arvalid <= 1;
       end 
@@ -380,7 +372,7 @@ module test;
       if(_saxi_arvalid && !_saxi_arready) begin
         _saxi_arvalid <= _saxi_arvalid;
       end 
-      if((th_ctrl == 24) && (_saxi_arready || !_saxi_arvalid)) begin
+      if((th_ctrl == 32) && (_saxi_arready || !_saxi_arvalid)) begin
         _saxi_araddr <= _th_ctrl_araddr_8;
         _saxi_arvalid <= 1;
       end 
@@ -388,14 +380,6 @@ module test;
       if(_saxi_arvalid && !_saxi_arready) begin
         _saxi_arvalid <= _saxi_arvalid;
       end 
-      if((th_ctrl == 29) && (_saxi_arready || !_saxi_arvalid)) begin
-        _saxi_araddr <= _th_ctrl_araddr_8;
-        _saxi_arvalid <= 1;
-      end 
-      __saxi_cond_8_1 <= 1;
-      if(_saxi_arvalid && !_saxi_arready) begin
-        _saxi_arvalid <= _saxi_arvalid;
-      end 
     end
   end
 
@@ -445,6 +429,10 @@ module test;
   localparam th_ctrl_35 = 35;
   localparam th_ctrl_36 = 36;
   localparam th_ctrl_37 = 37;
+  localparam th_ctrl_38 = 38;
+  localparam th_ctrl_39 = 39;
+  localparam th_ctrl_40 = 40;
+  localparam th_ctrl_41 = 41;
 
   always @(posedge CLK) begin
     if(RST) begin
@@ -456,9 +444,8 @@ module test;
       _th_ctrl_start_time_7 <= 0;
       _th_ctrl_araddr_8 <= 0;
       axim_rdata_14 <= 0;
-      _th_ctrl_v_9 <= 0;
+      _th_ctrl_busy_9 <= 0;
       axim_rdata_15 <= 0;
-      axim_rdata_16 <= 0;
       _th_ctrl_c_10 <= 0;
       _th_ctrl_end_time_11 <= 0;
       _th_ctrl_time_12 <= 0;
@@ -495,85 +482,77 @@ module test;
           th_ctrl <= th_ctrl_7;
         end
         th_ctrl_7: begin
-          if(_saxi_awready || !_saxi_awvalid) begin
+          if((outstanding_wcount_0 < 6) && (_saxi_awready || !_saxi_awvalid)) begin
             th_ctrl <= th_ctrl_8;
           end 
         end
         th_ctrl_8: begin
-          if((outstanding_wcount_0 < 6) && (_saxi_wready || !_saxi_wvalid)) begin
-            th_ctrl <= th_ctrl_9;
-          end 
+          th_ctrl <= th_ctrl_9;
         end
         th_ctrl_9: begin
-          _th_ctrl_awaddr_4 <= 12;
-          th_ctrl <= th_ctrl_10;
+          if(_saxi_wready || !_saxi_wvalid) begin
+            th_ctrl <= th_ctrl_10;
+          end 
         end
         th_ctrl_10: begin
-          _th_ctrl_b_6 <= 20;
+          _th_ctrl_awaddr_4 <= 12;
           th_ctrl <= th_ctrl_11;
         end
         th_ctrl_11: begin
-          $display("# b = %d", _th_ctrl_b_6);
+          _th_ctrl_b_6 <= 20;
           th_ctrl <= th_ctrl_12;
         end
         th_ctrl_12: begin
-          if(_saxi_awready || !_saxi_awvalid) begin
-            th_ctrl <= th_ctrl_13;
-          end 
+          $display("# b = %d", _th_ctrl_b_6);
+          th_ctrl <= th_ctrl_13;
         end
         th_ctrl_13: begin
-          if((outstanding_wcount_0 < 6) && (_saxi_wready || !_saxi_wvalid)) begin
+          if((outstanding_wcount_0 < 6) && (_saxi_awready || !_saxi_awvalid)) begin
             th_ctrl <= th_ctrl_14;
           end 
         end
         th_ctrl_14: begin
-          _th_ctrl_awaddr_4 <= 0;
           th_ctrl <= th_ctrl_15;
         end
         th_ctrl_15: begin
-          _th_ctrl_start_time_7 <= counter;
-          th_ctrl <= th_ctrl_16;
+          if(_saxi_wready || !_saxi_wvalid) begin
+            th_ctrl <= th_ctrl_16;
+          end 
         end
         th_ctrl_16: begin
-          $display("# start time = %d", _th_ctrl_start_time_7);
+          _th_ctrl_awaddr_4 <= 0;
           th_ctrl <= th_ctrl_17;
         end
         th_ctrl_17: begin
-          if(_saxi_awready || !_saxi_awvalid) begin
-            th_ctrl <= th_ctrl_18;
-          end 
+          _th_ctrl_start_time_7 <= counter;
+          th_ctrl <= th_ctrl_18;
         end
         th_ctrl_18: begin
-          if((outstanding_wcount_0 < 6) && (_saxi_wready || !_saxi_wvalid)) begin
-            th_ctrl <= th_ctrl_19;
-          end 
+          $display("# start time = %d", _th_ctrl_start_time_7);
+          th_ctrl <= th_ctrl_19;
         end
         th_ctrl_19: begin
-          _th_ctrl_araddr_8 <= 4;
-          th_ctrl <= th_ctrl_20;
+          if((outstanding_wcount_0 < 6) && (_saxi_awready || !_saxi_awvalid)) begin
+            th_ctrl <= th_ctrl_20;
+          end 
         end
         th_ctrl_20: begin
-          if(_saxi_arready || !_saxi_arvalid) begin
-            th_ctrl <= th_ctrl_21;
-          end 
+          th_ctrl <= th_ctrl_21;
         end
         th_ctrl_21: begin
-          if(_saxi_rready && _saxi_rvalid) begin
-            axim_rdata_14 <= _saxi_rdata;
-          end 
-          if(_saxi_rready && _saxi_rvalid) begin
+          if(_saxi_wready || !_saxi_wvalid) begin
             th_ctrl <= th_ctrl_22;
           end 
         end
         th_ctrl_22: begin
-          _th_ctrl_v_9 <= axim_rdata_14;
+          _th_ctrl_araddr_8 <= 4;
           th_ctrl <= th_ctrl_23;
         end
         th_ctrl_23: begin
-          if(_th_ctrl_v_9 == 0) begin
+          if(1) begin
             th_ctrl <= th_ctrl_24;
           end else begin
-            th_ctrl <= th_ctrl_28;
+            th_ctrl <= th_ctrl_31;
           end
         end
         th_ctrl_24: begin
@@ -582,61 +561,77 @@ module test;
           end 
         end
         th_ctrl_25: begin
-          if(_saxi_rready && _saxi_rvalid) begin
-            axim_rdata_15 <= _saxi_rdata;
-          end 
-          if(_saxi_rready && _saxi_rvalid) begin
-            th_ctrl <= th_ctrl_26;
-          end 
+          th_ctrl <= th_ctrl_26;
         end
         th_ctrl_26: begin
-          _th_ctrl_v_9 <= axim_rdata_15;
-          th_ctrl <= th_ctrl_27;
+          if(_saxi_rvalid) begin
+            axim_rdata_14 <= _saxi_rdata;
+          end 
+          if(_saxi_rvalid) begin
+            th_ctrl <= th_ctrl_27;
+          end 
         end
         th_ctrl_27: begin
-          th_ctrl <= th_ctrl_23;
+          _th_ctrl_busy_9 <= axim_rdata_14;
+          th_ctrl <= th_ctrl_28;
         end
         th_ctrl_28: begin
-          _th_ctrl_araddr_8 <= 16;
-          th_ctrl <= th_ctrl_29;
+          if(!_th_ctrl_busy_9) begin
+            th_ctrl <= th_ctrl_29;
+          end else begin
+            th_ctrl <= th_ctrl_30;
+          end
         end
         th_ctrl_29: begin
-          if(_saxi_arready || !_saxi_arvalid) begin
-            th_ctrl <= th_ctrl_30;
-          end 
+          th_ctrl <= th_ctrl_31;
         end
         th_ctrl_30: begin
-          if(_saxi_rready && _saxi_rvalid) begin
-            axim_rdata_16 <= _saxi_rdata;
-          end 
-          if(_saxi_rready && _saxi_rvalid) begin
-            th_ctrl <= th_ctrl_31;
-          end 
+          th_ctrl <= th_ctrl_23;
         end
         th_ctrl_31: begin
-          _th_ctrl_c_10 <= axim_rdata_16;
+          _th_ctrl_araddr_8 <= 16;
           th_ctrl <= th_ctrl_32;
         end
         th_ctrl_32: begin
-          $display("# c = %d", _th_ctrl_c_10);
-          th_ctrl <= th_ctrl_33;
+          if(_saxi_arready || !_saxi_arvalid) begin
+            th_ctrl <= th_ctrl_33;
+          end 
         end
         th_ctrl_33: begin
-          _th_ctrl_end_time_11 <= counter;
           th_ctrl <= th_ctrl_34;
         end
         th_ctrl_34: begin
-          $display("# end time = %d", _th_ctrl_end_time_11);
-          th_ctrl <= th_ctrl_35;
+          if(_saxi_rvalid) begin
+            axim_rdata_15 <= _saxi_rdata;
+          end 
+          if(_saxi_rvalid) begin
+            th_ctrl <= th_ctrl_35;
+          end 
         end
         th_ctrl_35: begin
-          _th_ctrl_time_12 <= _th_ctrl_end_time_11 - _th_ctrl_start_time_7;
+          _th_ctrl_c_10 <= axim_rdata_15;
           th_ctrl <= th_ctrl_36;
         end
         th_ctrl_36: begin
-          $display("# exec time = %d", _th_ctrl_time_12);
+          $display("# c = %d", _th_ctrl_c_10);
           th_ctrl <= th_ctrl_37;
         end
+        th_ctrl_37: begin
+          _th_ctrl_end_time_11 <= counter;
+          th_ctrl <= th_ctrl_38;
+        end
+        th_ctrl_38: begin
+          $display("# end time = %d", _th_ctrl_end_time_11);
+          th_ctrl <= th_ctrl_39;
+        end
+        th_ctrl_39: begin
+          _th_ctrl_time_12 <= _th_ctrl_end_time_11 - _th_ctrl_start_time_7;
+          th_ctrl <= th_ctrl_40;
+        end
+        th_ctrl_40: begin
+          $display("# exec time = %d", _th_ctrl_time_12);
+          th_ctrl <= th_ctrl_41;
+        end
       endcase
     end
   end
@@ -711,36 +706,36 @@ module add
   reg prev_arvalid_4;
   assign saxi_awready = (_saxi_register_fsm == 0) && (!writevalid_1 && !readvalid_2 && !saxi_bvalid && prev_awvalid_3);
   assign saxi_arready = (_saxi_register_fsm == 0) && (!readvalid_2 && !writevalid_1 && prev_arvalid_4 && !prev_awvalid_3);
-  reg [_saxi_maskwidth-1:0] _tmp_5;
-  wire signed [32-1:0] _tmp_6;
-  assign _tmp_6 = (_tmp_5 == 0)? _saxi_register_0 : 
-                  (_tmp_5 == 1)? _saxi_register_1 : 
-                  (_tmp_5 == 2)? _saxi_register_2 : 
-                  (_tmp_5 == 3)? _saxi_register_3 : 
-                  (_tmp_5 == 4)? _saxi_register_4 : 
-                  (_tmp_5 == 5)? _saxi_register_5 : 
-                  (_tmp_5 == 6)? _saxi_register_6 : 
-                  (_tmp_5 == 7)? _saxi_register_7 : 'hx;
-  wire _tmp_7;
-  assign _tmp_7 = (_tmp_5 == 0)? _saxi_flag_0 : 
-                  (_tmp_5 == 1)? _saxi_flag_1 : 
-                  (_tmp_5 == 2)? _saxi_flag_2 : 
-                  (_tmp_5 == 3)? _saxi_flag_3 : 
-                  (_tmp_5 == 4)? _saxi_flag_4 : 
-                  (_tmp_5 == 5)? _saxi_flag_5 : 
-                  (_tmp_5 == 6)? _saxi_flag_6 : 
-                  (_tmp_5 == 7)? _saxi_flag_7 : 'hx;
-  wire signed [32-1:0] _tmp_8;
-  assign _tmp_8 = (_tmp_5 == 0)? _saxi_resetval_0 : 
-                  (_tmp_5 == 1)? _saxi_resetval_1 : 
-                  (_tmp_5 == 2)? _saxi_resetval_2 : 
-                  (_tmp_5 == 3)? _saxi_resetval_3 : 
-                  (_tmp_5 == 4)? _saxi_resetval_4 : 
-                  (_tmp_5 == 5)? _saxi_resetval_5 : 
-                  (_tmp_5 == 6)? _saxi_resetval_6 : 
-                  (_tmp_5 == 7)? _saxi_resetval_7 : 'hx;
+  reg [_saxi_maskwidth-1:0] axis_maskaddr_5;
+  wire signed [32-1:0] axislite_rdata_6;
+  assign axislite_rdata_6 = (axis_maskaddr_5 == 0)? _saxi_register_0 : 
+                            (axis_maskaddr_5 == 1)? _saxi_register_1 : 
+                            (axis_maskaddr_5 == 2)? _saxi_register_2 : 
+                            (axis_maskaddr_5 == 3)? _saxi_register_3 : 
+                            (axis_maskaddr_5 == 4)? _saxi_register_4 : 
+                            (axis_maskaddr_5 == 5)? _saxi_register_5 : 
+                            (axis_maskaddr_5 == 6)? _saxi_register_6 : 
+                            (axis_maskaddr_5 == 7)? _saxi_register_7 : 'hx;
+  wire axislite_flag_7;
+  assign axislite_flag_7 = (axis_maskaddr_5 == 0)? _saxi_flag_0 : 
+                           (axis_maskaddr_5 == 1)? _saxi_flag_1 : 
+                           (axis_maskaddr_5 == 2)? _saxi_flag_2 : 
+                           (axis_maskaddr_5 == 3)? _saxi_flag_3 : 
+                           (axis_maskaddr_5 == 4)? _saxi_flag_4 : 
+                           (axis_maskaddr_5 == 5)? _saxi_flag_5 : 
+                           (axis_maskaddr_5 == 6)? _saxi_flag_6 : 
+                           (axis_maskaddr_5 == 7)? _saxi_flag_7 : 'hx;
+  wire signed [32-1:0] axislite_resetval_8;
+  assign axislite_resetval_8 = (axis_maskaddr_5 == 0)? _saxi_resetval_0 : 
+                               (axis_maskaddr_5 == 1)? _saxi_resetval_1 : 
+                               (axis_maskaddr_5 == 2)? _saxi_resetval_2 : 
+                               (axis_maskaddr_5 == 3)? _saxi_resetval_3 : 
+                               (axis_maskaddr_5 == 4)? _saxi_resetval_4 : 
+                               (axis_maskaddr_5 == 5)? _saxi_resetval_5 : 
+                               (axis_maskaddr_5 == 6)? _saxi_resetval_6 : 
+                               (axis_maskaddr_5 == 7)? _saxi_resetval_7 : 'hx;
   reg _saxi_cond_0_1;
-  assign saxi_wready = _saxi_register_fsm == 3;
+  assign saxi_wready = _saxi_register_fsm == 2;
   reg [32-1:0] th_add;
   localparam th_add_init = 0;
   reg signed [32-1:0] _th_add_a_0;
@@ -774,14 +769,6 @@ module add
       _saxi_flag_6 <= 0;
       _saxi_register_7 <= 0;
       _saxi_flag_7 <= 0;
-      _saxi_resetval_0 <= 0;
-      _saxi_resetval_1 <= 0;
-      _saxi_resetval_2 <= 0;
-      _saxi_resetval_3 <= 0;
-      _saxi_resetval_4 <= 0;
-      _saxi_resetval_5 <= 0;
-      _saxi_resetval_6 <= 0;
-      _saxi_resetval_7 <= 0;
     end else begin
       if(_saxi_cond_0_1) begin
         saxi_rvalid <= 0;
@@ -804,67 +791,67 @@ module add
         readvalid_2 <= 1;
       end 
       if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid)) begin
-        saxi_rdata <= _tmp_6;
+        saxi_rdata <= axislite_rdata_6;
         saxi_rvalid <= 1;
       end 
       _saxi_cond_0_1 <= 1;
       if(saxi_rvalid && !saxi_rready) begin
         saxi_rvalid <= saxi_rvalid;
       end 
-      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && _tmp_7 && (_tmp_5 == 0)) begin
-        _saxi_register_0 <= _tmp_8;
+      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && axislite_flag_7 && (axis_maskaddr_5 == 0)) begin
+        _saxi_register_0 <= axislite_resetval_8;
         _saxi_flag_0 <= 0;
       end 
-      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && _tmp_7 && (_tmp_5 == 1)) begin
-        _saxi_register_1 <= _tmp_8;
+      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && axislite_flag_7 && (axis_maskaddr_5 == 1)) begin
+        _saxi_register_1 <= axislite_resetval_8;
         _saxi_flag_1 <= 0;
       end 
-      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && _tmp_7 && (_tmp_5 == 2)) begin
-        _saxi_register_2 <= _tmp_8;
+      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && axislite_flag_7 && (axis_maskaddr_5 == 2)) begin
+        _saxi_register_2 <= axislite_resetval_8;
         _saxi_flag_2 <= 0;
       end 
-      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && _tmp_7 && (_tmp_5 == 3)) begin
-        _saxi_register_3 <= _tmp_8;
+      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && axislite_flag_7 && (axis_maskaddr_5 == 3)) begin
+        _saxi_register_3 <= axislite_resetval_8;
         _saxi_flag_3 <= 0;
       end 
-      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && _tmp_7 && (_tmp_5 == 4)) begin
-        _saxi_register_4 <= _tmp_8;
+      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && axislite_flag_7 && (axis_maskaddr_5 == 4)) begin
+        _saxi_register_4 <= axislite_resetval_8;
         _saxi_flag_4 <= 0;
       end 
-      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && _tmp_7 && (_tmp_5 == 5)) begin
-        _saxi_register_5 <= _tmp_8;
+      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && axislite_flag_7 && (axis_maskaddr_5 == 5)) begin
+        _saxi_register_5 <= axislite_resetval_8;
         _saxi_flag_5 <= 0;
       end 
-      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && _tmp_7 && (_tmp_5 == 6)) begin
-        _saxi_register_6 <= _tmp_8;
+      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && axislite_flag_7 && (axis_maskaddr_5 == 6)) begin
+        _saxi_register_6 <= axislite_resetval_8;
         _saxi_flag_6 <= 0;
       end 
-      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && _tmp_7 && (_tmp_5 == 7)) begin
-        _saxi_register_7 <= _tmp_8;
+      if((_saxi_register_fsm == 1) && (saxi_rready || !saxi_rvalid) && axislite_flag_7 && (axis_maskaddr_5 == 7)) begin
+        _saxi_register_7 <= axislite_resetval_8;
         _saxi_flag_7 <= 0;
       end 
-      if((_saxi_register_fsm == 3) && (saxi_wready && saxi_wvalid) && (_tmp_5 == 0)) begin
+      if((_saxi_register_fsm == 2) && saxi_wvalid && (axis_maskaddr_5 == 0)) begin
         _saxi_register_0 <= saxi_wdata;
       end 
-      if((_saxi_register_fsm == 3) && (saxi_wready && saxi_wvalid) && (_tmp_5 == 1)) begin
+      if((_saxi_register_fsm == 2) && saxi_wvalid && (axis_maskaddr_5 == 1)) begin
         _saxi_register_1 <= saxi_wdata;
       end 
-      if((_saxi_register_fsm == 3) && (saxi_wready && saxi_wvalid) && (_tmp_5 == 2)) begin
+      if((_saxi_register_fsm == 2) && saxi_wvalid && (axis_maskaddr_5 == 2)) begin
         _saxi_register_2 <= saxi_wdata;
       end 
-      if((_saxi_register_fsm == 3) && (saxi_wready && saxi_wvalid) && (_tmp_5 == 3)) begin
+      if((_saxi_register_fsm == 2) && saxi_wvalid && (axis_maskaddr_5 == 3)) begin
         _saxi_register_3 <= saxi_wdata;
       end 
-      if((_saxi_register_fsm == 3) && (saxi_wready && saxi_wvalid) && (_tmp_5 == 4)) begin
+      if((_saxi_register_fsm == 2) && saxi_wvalid && (axis_maskaddr_5 == 4)) begin
         _saxi_register_4 <= saxi_wdata;
       end 
-      if((_saxi_register_fsm == 3) && (saxi_wready && saxi_wvalid) && (_tmp_5 == 5)) begin
+      if((_saxi_register_fsm == 2) && saxi_wvalid && (axis_maskaddr_5 == 5)) begin
         _saxi_register_5 <= saxi_wdata;
       end 
-      if((_saxi_register_fsm == 3) && (saxi_wready && saxi_wvalid) && (_tmp_5 == 6)) begin
+      if((_saxi_register_fsm == 2) && saxi_wvalid && (axis_maskaddr_5 == 6)) begin
         _saxi_register_6 <= saxi_wdata;
       end 
-      if((_saxi_register_fsm == 3) && (saxi_wready && saxi_wvalid) && (_tmp_5 == 7)) begin
+      if((_saxi_register_fsm == 2) && saxi_wvalid && (axis_maskaddr_5 == 7)) begin
         _saxi_register_7 <= saxi_wdata;
       end 
       if((_saxi_register_0 == 1) && (th_add == 2) && 1) begin
@@ -891,116 +878,132 @@ module add
       if((_saxi_register_0 == 1) && (th_add == 2) && 0) begin
         _saxi_register_7 <= 0;
       end 
-      if((th_add == 6) && 0) begin
-        _saxi_register_0 <= _th_add_c_2;
+      if((th_add == 3) && 0) begin
+        _saxi_register_0 <= 1;
         _saxi_flag_0 <= 0;
       end 
-      if((th_add == 6) && 0) begin
-        _saxi_register_1 <= _th_add_c_2;
+      if((th_add == 3) && 1) begin
+        _saxi_register_1 <= 1;
         _saxi_flag_1 <= 0;
       end 
-      if((th_add == 6) && 0) begin
-        _saxi_register_2 <= _th_add_c_2;
+      if((th_add == 3) && 0) begin
+        _saxi_register_2 <= 1;
         _saxi_flag_2 <= 0;
       end 
-      if((th_add == 6) && 0) begin
-        _saxi_register_3 <= _th_add_c_2;
+      if((th_add == 3) && 0) begin
+        _saxi_register_3 <= 1;
         _saxi_flag_3 <= 0;
       end 
-      if((th_add == 6) && 1) begin
-        _saxi_register_4 <= _th_add_c_2;
+      if((th_add == 3) && 0) begin
+        _saxi_register_4 <= 1;
         _saxi_flag_4 <= 0;
       end 
-      if((th_add == 6) && 0) begin
-        _saxi_register_5 <= _th_add_c_2;
+      if((th_add == 3) && 0) begin
+        _saxi_register_5 <= 1;
         _saxi_flag_5 <= 0;
       end 
-      if((th_add == 6) && 0) begin
-        _saxi_register_6 <= _th_add_c_2;
+      if((th_add == 3) && 0) begin
+        _saxi_register_6 <= 1;
         _saxi_flag_6 <= 0;
       end 
-      if((th_add == 6) && 0) begin
-        _saxi_register_7 <= _th_add_c_2;
+      if((th_add == 3) && 0) begin
+        _saxi_register_7 <= 1;
         _saxi_flag_7 <= 0;
       end 
       if((th_add == 7) && 0) begin
-        _saxi_register_0 <= 1;
-        _saxi_flag_0 <= 1;
-        _saxi_resetval_0 <= 0;
+        _saxi_register_0 <= _th_add_c_2;
+        _saxi_flag_0 <= 0;
+      end 
+      if((th_add == 7) && 0) begin
+        _saxi_register_1 <= _th_add_c_2;
+        _saxi_flag_1 <= 0;
+      end 
+      if((th_add == 7) && 0) begin
+        _saxi_register_2 <= _th_add_c_2;
+        _saxi_flag_2 <= 0;
+      end 
+      if((th_add == 7) && 0) begin
+        _saxi_register_3 <= _th_add_c_2;
+        _saxi_flag_3 <= 0;
       end 
       if((th_add == 7) && 1) begin
-        _saxi_register_1 <= 1;
-        _saxi_flag_1 <= 1;
-        _saxi_resetval_1 <= 0;
+        _saxi_register_4 <= _th_add_c_2;
+        _saxi_flag_4 <= 0;
       end 
       if((th_add == 7) && 0) begin
-        _saxi_register_2 <= 1;
-        _saxi_flag_2 <= 1;
-        _saxi_resetval_2 <= 0;
+        _saxi_register_5 <= _th_add_c_2;
+        _saxi_flag_5 <= 0;
       end 
       if((th_add == 7) && 0) begin
-        _saxi_register_3 <= 1;
-        _saxi_flag_3 <= 1;
-        _saxi_resetval_3 <= 0;
+        _saxi_register_6 <= _th_add_c_2;
+        _saxi_flag_6 <= 0;
       end 
       if((th_add == 7) && 0) begin
-        _saxi_register_4 <= 1;
-        _saxi_flag_4 <= 1;
-        _saxi_resetval_4 <= 0;
+        _saxi_register_7 <= _th_add_c_2;
+        _saxi_flag_7 <= 0;
       end 
-      if((th_add == 7) && 0) begin
-        _saxi_register_5 <= 1;
-        _saxi_flag_5 <= 1;
-        _saxi_resetval_5 <= 0;
+      if((th_add == 8) && 0) begin
+        _saxi_register_0 <= 0;
+        _saxi_flag_0 <= 0;
       end 
-      if((th_add == 7) && 0) begin
-        _saxi_register_6 <= 1;
-        _saxi_flag_6 <= 1;
-        _saxi_resetval_6 <= 0;
+      if((th_add == 8) && 1) begin
+        _saxi_register_1 <= 0;
+        _saxi_flag_1 <= 0;
       end 
-      if((th_add == 7) && 0) begin
-        _saxi_register_7 <= 1;
-        _saxi_flag_7 <= 1;
-        _saxi_resetval_7 <= 0;
+      if((th_add == 8) && 0) begin
+        _saxi_register_2 <= 0;
+        _saxi_flag_2 <= 0;
+      end 
+      if((th_add == 8) && 0) begin
+        _saxi_register_3 <= 0;
+        _saxi_flag_3 <= 0;
+      end 
+      if((th_add == 8) && 0) begin
+        _saxi_register_4 <= 0;
+        _saxi_flag_4 <= 0;
+      end 
+      if((th_add == 8) && 0) begin
+        _saxi_register_5 <= 0;
+        _saxi_flag_5 <= 0;
+      end 
+      if((th_add == 8) && 0) begin
+        _saxi_register_6 <= 0;
+        _saxi_flag_6 <= 0;
+      end 
+      if((th_add == 8) && 0) begin
+        _saxi_register_7 <= 0;
+        _saxi_flag_7 <= 0;
       end 
     end
   end
 
   localparam _saxi_register_fsm_1 = 1;
   localparam _saxi_register_fsm_2 = 2;
-  localparam _saxi_register_fsm_3 = 3;
 
   always @(posedge CLK) begin
     if(RST) begin
       _saxi_register_fsm <= _saxi_register_fsm_init;
+      axis_maskaddr_5 <= 0;
     end else begin
       case(_saxi_register_fsm)
         _saxi_register_fsm_init: begin
           if(readvalid_2 || writevalid_1) begin
-            _tmp_5 <= (addr_0 >> _saxi_shift) & _saxi_mask;
+            axis_maskaddr_5 <= (addr_0 >> _saxi_shift) & _saxi_mask;
           end 
           if(readvalid_2) begin
             _saxi_register_fsm <= _saxi_register_fsm_1;
           end 
           if(writevalid_1) begin
-            _saxi_register_fsm <= _saxi_register_fsm_3;
-          end 
-        end
-        _saxi_register_fsm_1: begin
-          if(saxi_rready && saxi_rvalid) begin
-            _saxi_register_fsm <= _saxi_register_fsm_init;
-          end 
-          if((saxi_rready || !saxi_rvalid) && !(saxi_rready && saxi_rvalid)) begin
             _saxi_register_fsm <= _saxi_register_fsm_2;
           end 
         end
-        _saxi_register_fsm_2: begin
-          if(saxi_rready && saxi_rvalid) begin
+        _saxi_register_fsm_1: begin
+          if(saxi_rready || !saxi_rvalid) begin
             _saxi_register_fsm <= _saxi_register_fsm_init;
           end 
         end
-        _saxi_register_fsm_3: begin
-          if(saxi_wready && saxi_wvalid) begin
+        _saxi_register_fsm_2: begin
+          if(saxi_wvalid) begin
             _saxi_register_fsm <= _saxi_register_fsm_init;
           end 
         end
@@ -1017,6 +1020,7 @@ module add
   localparam th_add_7 = 7;
   localparam th_add_8 = 8;
   localparam th_add_9 = 9;
+  localparam th_add_10 = 10;
 
   always @(posedge CLK) begin
     if(RST) begin
@@ -1033,7 +1037,7 @@ module add
           if(1) begin
             th_add <= th_add_2;
           end else begin
-            th_add <= th_add_9;
+            th_add <= th_add_10;
           end
         end
         th_add_2: begin
@@ -1042,24 +1046,27 @@ module add
           end 
         end
         th_add_3: begin
-          _th_add_a_0 <= _saxi_register_2;
           th_add <= th_add_4;
         end
         th_add_4: begin
-          _th_add_b_1 <= _saxi_register_3;
+          _th_add_a_0 <= _saxi_register_2;
           th_add <= th_add_5;
         end
         th_add_5: begin
-          _th_add_c_2 <= _th_add_a_0 + _th_add_b_1;
+          _th_add_b_1 <= _saxi_register_3;
           th_add <= th_add_6;
         end
         th_add_6: begin
+          _th_add_c_2 <= _th_add_a_0 + _th_add_b_1;
           th_add <= th_add_7;
         end
         th_add_7: begin
           th_add <= th_add_8;
         end
         th_add_8: begin
+          th_add <= th_add_9;
+        end
+        th_add_9: begin
           th_add <= th_add_1;
         end
       endcase
