@@ -19,11 +19,6 @@ module test;
     .y(y)
   );
 
-  initial begin
-    $dumpfile("uut.vcd");
-    $dumpvars(0, uut);
-  end
-
   initial begin
     CLK = 0;
     forever begin
@@ -81,6 +76,7 @@ module blinkled
 endmodule
 """
 
+
 def test():
     veriloggen.reset()
     test_module = seq_compare.mkTest()
