@@ -31,12 +31,6 @@ module test
   reg reset_done;
   reg end_of_sim;
 
-  initial begin
-    $dumpfile("uut.vcd");
-    $dumpvars(0, uut);
-  end
-
-
   initial begin
     CLK = 0;
     forever begin
