@@ -20,46 +20,46 @@ def mkMain():
     myaxi.disable_write()
 
     fsm = FSM(m, 'fsm', clk, rst)
-    sum = m.Reg('sum', 32, initval=0)
 
     # read address (1)
-    araddr = 1024
-    expected_sum = (araddr // 4)
-
-    ack = myaxi.read_request(araddr, cond=fsm)
+    araddr1 = 1024
+    ack = myaxi.read_request(araddr1, cond=fsm)
     fsm.If(ack).goto_next()
 
     # read data (1)
     data, valid = myaxi.read_data(cond=fsm)
+    sum = m.Reg('sum', 32, initval=0)
 
     fsm.If(valid)(
-        sum(sum + data)
+        sum.add(data)
     )
-    fsm.Then().goto_next()
+    fsm.If(valid).goto_next()
 
     # read address (2)
-    araddr = 1024 + 1024
-    expected_sum += (araddr // 4)
-
-    ack = myaxi.read_request(araddr, cond=fsm)
+    araddr2 = 1024 + 1024
+    ack = myaxi.read_request(araddr2, cond=fsm)
     fsm.If(ack).goto_next()
 
     # read data (2)
     data, valid = myaxi.read_data(cond=fsm)
 
     fsm.If(valid)(
-        sum(sum + data)
+        sum.add(data)
     )
-    fsm.Then().goto_next()
+    fsm.If(valid).goto_next()
 
+    # verify
+    expected_sum = araddr1 // 4 + araddr2 // 4
     fsm(
-        Systask('display', 'sum=%d expected_sum=%d', sum, expected_sum),
-        If(NotEql(sum, expected_sum))(Display('# verify: FAILED')).Else(Display('# verify: PASSED'))
+        Systask('display', 'sum=%d expected_sum=%d', sum, expected_sum)
+    )
+    fsm.If(sum == expected_sum)(
+        Systask('display', '# verify: PASSED')
+    ).Else(
+        Systask('display', '# verify: FAILED')
     )
     fsm.goto_next()
 
-    fsm.make_always()
-
     return m
 
 
@@ -76,8 +76,63 @@ def mkTest(memimg_name=None):
     clk = ports['CLK']
     rst = ports['RST']
 
-    memory = axi.AxiMemoryModel(m, 'memory', clk, rst)
-    memory.connect(ports, 'myaxi')
+    # awready (no stall)
+    awready = ports['myaxi_awready']
+    _awready = m.TmpWireLike(awready)
+    _awready.assign(1)
+    m.Always()(awready(_awready))
+
+    # wready (no stall)
+    wready = ports['myaxi_wready']
+    _wready = m.TmpWireLike(wready)
+    _wready.assign(1)
+    m.Always()(wready(_wready))
+
+    # bvalid (no stall)
+    bvalid = ports['myaxi_bvalid']
+    _bvalid = m.TmpWireLike(bvalid)
+    _bvalid.assign(0)
+    m.Always()(bvalid(_bvalid))
+
+    # arready, rvalid, rdata
+    raddr_fsm = FSM(m, 'raddr', clk, rst)
+    raddr_fsm(
+        ports['myaxi_arready'](0),
+        ports['myaxi_rdata'](-1),
+        ports['myaxi_rvalid'](0),
+    )
+    raddr_fsm.If(ports['myaxi_arvalid']).goto_next()
+
+    raddr_fsm.If(ports['myaxi_arvalid'])(
+        ports['myaxi_arready'](1),
+        ports['myaxi_rdata']((ports['myaxi_araddr'] >> 2) - 1)
+    )
+    raddr_fsm.goto_next()
+
+    raddr_fsm(
+        ports['myaxi_arready'](0),
+    )
+    raddr_fsm.goto_next()
+
+    ack = Ors(ports['myaxi_rready'], Not(ports['myaxi_rvalid']))
+
+    raddr_fsm.If(ack)(
+        ports['myaxi_rdata'].inc(),
+        ports['myaxi_rvalid'](1),
+    )
+    raddr_fsm.Delay(1)(
+        ports['myaxi_rvalid'](0),
+    )
+    raddr_fsm.If(Ands(ports['myaxi_rvalid'], Not(ports['myaxi_rready'])))(
+        ports['myaxi_rvalid'](ports['myaxi_rvalid']),
+    )
+    raddr_fsm.If(Ands(ports['myaxi_rvalid'], ports['myaxi_rready'])).goto_next()
+
+    raddr_fsm.goto_next()
+
+    raddr_fsm.goto_init()
+
+    raddr_fsm.make_always()
 
     uut = m.Instance(main, 'uut',
                      params=m.connect_params(main),
@@ -100,9 +155,10 @@ def run(filename='tmp.v', simtype='iverilog', outputfile=None):
     if outputfile is None:
         outputfile = os.path.splitext(os.path.basename(__file__))[0] + '.out'
 
-    memimg_name = 'memimg_' + outputfile
+    # memimg_name = 'memimg_' + outputfile
 
-    test = mkTest(memimg_name=memimg_name)
+    # test = mkTest(memimg_name=memimg_name)
+    test = mkTest()
 
     if filename is not None:
         test.to_verilog(filename)
