@@ -22,19 +22,23 @@ def mkMain():
     fsm = FSM(m, 'fsm', clk, rst)
 
     # read address
-    addr, counter, valid = myaxi.pull_read_request_counter(cond=fsm)
+    addr, length, valid = myaxi.pull_read_request(cond=fsm)
     rdata = m.Reg('rdata', 32, initval=0)
+    rlen = m.Reg('rlen', 32, initval=0)
+    rlast = rlen <= 1
     fsm.If(valid)(
-        rdata(addr >> 2)
+        rdata(addr >> 2),
+        rlen(length)
     )
     fsm.If(valid).goto_next()
 
     # read rdata
-    ack, valid, last = myaxi.push_read_data(rdata, counter, cond=fsm)
+    ack = myaxi.push_read_data(rdata, rlast, cond=fsm)
     fsm.If(ack)(
-        rdata(rdata + 1)
+        rdata(rdata + 1),
+        rlen.dec()
     )
-    fsm.If(valid, last).goto_next()
+    fsm.If(ack, rlast).goto_next()
 
     fsm.goto_init()
 
@@ -60,43 +64,47 @@ def mkTest():
     _axi.connect(ports, 'myaxi')
 
     fsm = FSM(m, 'fsm', clk, rst)
-    sum = m.Reg('sum', 32, initval=0)
 
-    # read address (1)
-    araddr = 1024
-    arlen = 64
-    expected_sum = (araddr // 4 + araddr // 4 + arlen - 1) * arlen // 2
-
-    ack, counter = _axi.read_request_counter(araddr, arlen, cond=fsm)
+    # read request (1)
+    araddr1 = 1024
+    arlen1 = 64
+    ack = _axi.read_request(araddr1, arlen1, cond=fsm)
     fsm.If(ack).goto_next()
 
     # read data (1)
-    data, valid, last = _axi.read_data(counter, cond=fsm)
+    data, valid, last = _axi.read_data(cond=fsm)
+    sum = m.Reg('sum', width=32, initval=0)
 
     fsm.If(valid)(
-        sum(sum + data)
+        sum.add(data)
     )
-    fsm.Then().If(last).goto_next()
+    fsm.If(valid, last).goto_next()
 
-    # read address (2)
-    araddr = 1024 + 1024
-    arlen = 128
-    expected_sum += (araddr // 4 + araddr // 4 + arlen - 1) * arlen // 2
-
-    ack, counter = _axi.read_request_counter(araddr, arlen, cond=fsm)
+    # read request (2)
+    araddr2 = 1024 + 1024
+    arlen2 = 64 + 64
+    ack = _axi.read_request(araddr2, arlen2, cond=fsm)
     fsm.If(ack).goto_next()
 
     # read data (2)
-    data, valid, last = _axi.read_data(counter, cond=fsm)
+    data, valid, last = _axi.read_data(cond=fsm)
 
     fsm.If(valid)(
-        sum(sum + data)
+        sum.add(data)
     )
-    fsm.Then().If(last).goto_next()
+    fsm.If(valid, last).goto_next()
 
+    # verify
+    expected_sum = (((araddr1 // 4 + araddr1 // 4 + arlen1 - 1) * arlen1) // 2 +
+                    ((araddr2 // 4 + araddr2 // 4 + arlen2 - 1) * arlen2) // 2)
     fsm(
         Systask('display', 'sum=%d expected_sum=%d', sum, expected_sum)
     )
+    fsm.If(sum == expected_sum)(
+        Systask('display', '# verify: PASSED')
+    ).Else(
+        Systask('display', '# verify: FAILED')
+    )
     fsm.goto_next()
 
     uut = m.Instance(main, 'uut',
@@ -115,13 +123,27 @@ def mkTest():
     return m
 
 
-if __name__ == '__main__':
+def run(filename='tmp.v', simtype='iverilog', outputfile=None):
+
+    if outputfile is None:
+        outputfile = os.path.splitext(os.path.basename(__file__))[0] + '.out'
+
+    # memimg_name = 'memimg_' + outputfile
+
+    # test = mkTest(memimg_name=memimg_name)
     test = mkTest()
-    verilog = test.to_verilog('tmp.v')
-    print(verilog)
 
-    sim = simulation.Simulator(test)
-    rslt = sim.run()
+    if filename is not None:
+        test.to_verilog(filename)
+
+    sim = simulation.Simulator(test, sim=simtype)
+    rslt = sim.run(outputfile=outputfile)
+    lines = rslt.splitlines()
+    if simtype == 'verilator' and lines[-1].startswith('-'):
+        rslt = '\n'.join(lines[:-1])
+    return rslt
+
+
+if __name__ == '__main__':
+    rslt = run(filename='tmp.v')
     print(rslt)
-
-    # sim.view_waveform()
