@@ -19,12 +19,6 @@ module test;
   );
 
 
-  initial begin
-    $dumpfile("uut.vcd");
-    $dumpvars(0, uut, uut_CLK, uut_RST, uut_LED);
-  end
-
-
   initial begin
     uut_CLK = 0;
     forever begin
@@ -74,6 +68,7 @@ module blinkled
 endmodule
 """
 
+
 def test():
     veriloggen.reset()
     test_module = types_saturate_add.mkTest()
