@@ -5,4 +5,4 @@ from .axim import AXIM, AXIMLite, AXIMVerify, AXIMLiteVerify
 from .axis import AXIS, AXISLite, AXISRegister, AXISLiteRegister
 from .axistreamin import AXIStreamIn, AXIStreamInFifo
 from .axistreamout import AXIStreamOut, AXIStreamOutFifo
-from .axim_for_axistream import AXIM_for_AXIStreamIn, AXIM_for_AXIStreamOut, AXIM2
+from .axim_for_axistream import AXIM_for_AXIStreamIn, AXIM_for_AXIStreamOut
